# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DnsControlPolicyArgs', 'DnsControlPolicy']

@pulumi.input_type
class DnsControlPolicyArgs:
    def __init__(__self__, *,
                 destination: pulumi.Input[builtins.str],
                 destination_type: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 internet_firewall_id: Optional[pulumi.Input[builtins.str]] = None,
                 sources: Optional[pulumi.Input[Sequence[pulumi.Input['DnsControlPolicySourceArgs']]]] = None,
                 status: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a DnsControlPolicy resource.
        :param pulumi.Input[builtins.str] destination: 访问目的，可以是域名或域名地址簿的唯一标识ID。当前仅支持一个地址簿。
        :param pulumi.Input[builtins.str] destination_type: 访问目的的类型。domain：域名；group：域名地址簿。
        :param pulumi.Input[builtins.str] description: 策略的描述信息。
        :param pulumi.Input[builtins.str] internet_firewall_id: 互联网边界防火墙实例ID。
        :param pulumi.Input[builtins.bool] status: 域名黑名单访问控制策略的开关状态。false：关闭；true：开启。
        """
        pulumi.set(__self__, "destination", destination)
        pulumi.set(__self__, "destination_type", destination_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if internet_firewall_id is not None:
            pulumi.set(__self__, "internet_firewall_id", internet_firewall_id)
        if sources is not None:
            pulumi.set(__self__, "sources", sources)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def destination(self) -> pulumi.Input[builtins.str]:
        """
        访问目的，可以是域名或域名地址簿的唯一标识ID。当前仅支持一个地址簿。
        """
        return pulumi.get(self, "destination")

    @destination.setter
    def destination(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "destination", value)

    @property
    @pulumi.getter(name="destinationType")
    def destination_type(self) -> pulumi.Input[builtins.str]:
        """
        访问目的的类型。domain：域名；group：域名地址簿。
        """
        return pulumi.get(self, "destination_type")

    @destination_type.setter
    def destination_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "destination_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        策略的描述信息。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="internetFirewallId")
    def internet_firewall_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        互联网边界防火墙实例ID。
        """
        return pulumi.get(self, "internet_firewall_id")

    @internet_firewall_id.setter
    def internet_firewall_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "internet_firewall_id", value)

    @property
    @pulumi.getter
    def sources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DnsControlPolicySourceArgs']]]]:
        return pulumi.get(self, "sources")

    @sources.setter
    def sources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DnsControlPolicySourceArgs']]]]):
        pulumi.set(self, "sources", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        域名黑名单访问控制策略的开关状态。false：关闭；true：开启。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _DnsControlPolicyState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 destination: Optional[pulumi.Input[builtins.str]] = None,
                 destination_group_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 destination_type: Optional[pulumi.Input[builtins.str]] = None,
                 domain_list_v1s: Optional[pulumi.Input[Sequence[pulumi.Input['DnsControlPolicyDomainListV1Args']]]] = None,
                 domain_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 hit_cnt: Optional[pulumi.Input[builtins.int]] = None,
                 internet_firewall_id: Optional[pulumi.Input[builtins.str]] = None,
                 last_hit_time: Optional[pulumi.Input[builtins.int]] = None,
                 rule_id: Optional[pulumi.Input[builtins.str]] = None,
                 sources: Optional[pulumi.Input[Sequence[pulumi.Input['DnsControlPolicySourceArgs']]]] = None,
                 status: Optional[pulumi.Input[builtins.bool]] = None,
                 use_count: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering DnsControlPolicy resources.
        :param pulumi.Input[builtins.str] account_id: 用户的唯一标识ID。
        :param pulumi.Input[builtins.str] description: 策略的描述信息。
        :param pulumi.Input[builtins.str] destination: 访问目的，可以是域名或域名地址簿的唯一标识ID。当前仅支持一个地址簿。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] destination_group_lists: 域名地址簿名称列表。
        :param pulumi.Input[builtins.str] destination_type: 访问目的的类型。domain：域名；group：域名地址簿。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] domain_lists: 域名列表。
        :param pulumi.Input[builtins.int] hit_cnt: 命中计数，表示该域名黑名单访问控制策略被触发的次数。
        :param pulumi.Input[builtins.str] internet_firewall_id: 互联网边界防火墙实例ID。
        :param pulumi.Input[builtins.int] last_hit_time: 最近命中时间戳，表示该域名黑名单访问控制策略最后一次被触发的时间。
        :param pulumi.Input[builtins.str] rule_id: 访问控制策略的唯一标识ID。
        :param pulumi.Input[builtins.bool] status: 域名黑名单访问控制策略的开关状态。false：关闭；true：开启。
        :param pulumi.Input[builtins.int] use_count: 该域名黑名单访问控制策略占用的策略数量。
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if destination is not None:
            pulumi.set(__self__, "destination", destination)
        if destination_group_lists is not None:
            pulumi.set(__self__, "destination_group_lists", destination_group_lists)
        if destination_type is not None:
            pulumi.set(__self__, "destination_type", destination_type)
        if domain_list_v1s is not None:
            pulumi.set(__self__, "domain_list_v1s", domain_list_v1s)
        if domain_lists is not None:
            pulumi.set(__self__, "domain_lists", domain_lists)
        if hit_cnt is not None:
            pulumi.set(__self__, "hit_cnt", hit_cnt)
        if internet_firewall_id is not None:
            pulumi.set(__self__, "internet_firewall_id", internet_firewall_id)
        if last_hit_time is not None:
            pulumi.set(__self__, "last_hit_time", last_hit_time)
        if rule_id is not None:
            pulumi.set(__self__, "rule_id", rule_id)
        if sources is not None:
            pulumi.set(__self__, "sources", sources)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if use_count is not None:
            pulumi.set(__self__, "use_count", use_count)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户的唯一标识ID。
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        策略的描述信息。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def destination(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问目的，可以是域名或域名地址簿的唯一标识ID。当前仅支持一个地址簿。
        """
        return pulumi.get(self, "destination")

    @destination.setter
    def destination(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "destination", value)

    @property
    @pulumi.getter(name="destinationGroupLists")
    def destination_group_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        域名地址簿名称列表。
        """
        return pulumi.get(self, "destination_group_lists")

    @destination_group_lists.setter
    def destination_group_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "destination_group_lists", value)

    @property
    @pulumi.getter(name="destinationType")
    def destination_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问目的的类型。domain：域名；group：域名地址簿。
        """
        return pulumi.get(self, "destination_type")

    @destination_type.setter
    def destination_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "destination_type", value)

    @property
    @pulumi.getter(name="domainListV1s")
    def domain_list_v1s(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DnsControlPolicyDomainListV1Args']]]]:
        return pulumi.get(self, "domain_list_v1s")

    @domain_list_v1s.setter
    def domain_list_v1s(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DnsControlPolicyDomainListV1Args']]]]):
        pulumi.set(self, "domain_list_v1s", value)

    @property
    @pulumi.getter(name="domainLists")
    def domain_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        域名列表。
        """
        return pulumi.get(self, "domain_lists")

    @domain_lists.setter
    def domain_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "domain_lists", value)

    @property
    @pulumi.getter(name="hitCnt")
    def hit_cnt(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        命中计数，表示该域名黑名单访问控制策略被触发的次数。
        """
        return pulumi.get(self, "hit_cnt")

    @hit_cnt.setter
    def hit_cnt(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "hit_cnt", value)

    @property
    @pulumi.getter(name="internetFirewallId")
    def internet_firewall_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        互联网边界防火墙实例ID。
        """
        return pulumi.get(self, "internet_firewall_id")

    @internet_firewall_id.setter
    def internet_firewall_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "internet_firewall_id", value)

    @property
    @pulumi.getter(name="lastHitTime")
    def last_hit_time(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        最近命中时间戳，表示该域名黑名单访问控制策略最后一次被触发的时间。
        """
        return pulumi.get(self, "last_hit_time")

    @last_hit_time.setter
    def last_hit_time(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "last_hit_time", value)

    @property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问控制策略的唯一标识ID。
        """
        return pulumi.get(self, "rule_id")

    @rule_id.setter
    def rule_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_id", value)

    @property
    @pulumi.getter
    def sources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DnsControlPolicySourceArgs']]]]:
        return pulumi.get(self, "sources")

    @sources.setter
    def sources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DnsControlPolicySourceArgs']]]]):
        pulumi.set(self, "sources", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        域名黑名单访问控制策略的开关状态。false：关闭；true：开启。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="useCount")
    def use_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        该域名黑名单访问控制策略占用的策略数量。
        """
        return pulumi.get(self, "use_count")

    @use_count.setter
    def use_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "use_count", value)


@pulumi.type_token("bytepluscc:firewallcenter/dnsControlPolicy:DnsControlPolicy")
class DnsControlPolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 destination: Optional[pulumi.Input[builtins.str]] = None,
                 destination_type: Optional[pulumi.Input[builtins.str]] = None,
                 internet_firewall_id: Optional[pulumi.Input[builtins.str]] = None,
                 sources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DnsControlPolicySourceArgs', 'DnsControlPolicySourceArgsDict']]]]] = None,
                 status: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        域名黑名单访问控制策略。

        ## Import

        ```sh
        $ pulumi import bytepluscc:firewallcenter/dnsControlPolicy:DnsControlPolicy example "rule_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 策略的描述信息。
        :param pulumi.Input[builtins.str] destination: 访问目的，可以是域名或域名地址簿的唯一标识ID。当前仅支持一个地址簿。
        :param pulumi.Input[builtins.str] destination_type: 访问目的的类型。domain：域名；group：域名地址簿。
        :param pulumi.Input[builtins.str] internet_firewall_id: 互联网边界防火墙实例ID。
        :param pulumi.Input[builtins.bool] status: 域名黑名单访问控制策略的开关状态。false：关闭；true：开启。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DnsControlPolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        域名黑名单访问控制策略。

        ## Import

        ```sh
        $ pulumi import bytepluscc:firewallcenter/dnsControlPolicy:DnsControlPolicy example "rule_id"
        ```

        :param str resource_name: The name of the resource.
        :param DnsControlPolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DnsControlPolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 destination: Optional[pulumi.Input[builtins.str]] = None,
                 destination_type: Optional[pulumi.Input[builtins.str]] = None,
                 internet_firewall_id: Optional[pulumi.Input[builtins.str]] = None,
                 sources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DnsControlPolicySourceArgs', 'DnsControlPolicySourceArgsDict']]]]] = None,
                 status: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DnsControlPolicyArgs.__new__(DnsControlPolicyArgs)

            __props__.__dict__["description"] = description
            if destination is None and not opts.urn:
                raise TypeError("Missing required property 'destination'")
            __props__.__dict__["destination"] = destination
            if destination_type is None and not opts.urn:
                raise TypeError("Missing required property 'destination_type'")
            __props__.__dict__["destination_type"] = destination_type
            __props__.__dict__["internet_firewall_id"] = internet_firewall_id
            __props__.__dict__["sources"] = sources
            __props__.__dict__["status"] = status
            __props__.__dict__["account_id"] = None
            __props__.__dict__["destination_group_lists"] = None
            __props__.__dict__["domain_list_v1s"] = None
            __props__.__dict__["domain_lists"] = None
            __props__.__dict__["hit_cnt"] = None
            __props__.__dict__["last_hit_time"] = None
            __props__.__dict__["rule_id"] = None
            __props__.__dict__["use_count"] = None
        super(DnsControlPolicy, __self__).__init__(
            'bytepluscc:firewallcenter/dnsControlPolicy:DnsControlPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            destination: Optional[pulumi.Input[builtins.str]] = None,
            destination_group_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            destination_type: Optional[pulumi.Input[builtins.str]] = None,
            domain_list_v1s: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DnsControlPolicyDomainListV1Args', 'DnsControlPolicyDomainListV1ArgsDict']]]]] = None,
            domain_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            hit_cnt: Optional[pulumi.Input[builtins.int]] = None,
            internet_firewall_id: Optional[pulumi.Input[builtins.str]] = None,
            last_hit_time: Optional[pulumi.Input[builtins.int]] = None,
            rule_id: Optional[pulumi.Input[builtins.str]] = None,
            sources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DnsControlPolicySourceArgs', 'DnsControlPolicySourceArgsDict']]]]] = None,
            status: Optional[pulumi.Input[builtins.bool]] = None,
            use_count: Optional[pulumi.Input[builtins.int]] = None) -> 'DnsControlPolicy':
        """
        Get an existing DnsControlPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: 用户的唯一标识ID。
        :param pulumi.Input[builtins.str] description: 策略的描述信息。
        :param pulumi.Input[builtins.str] destination: 访问目的，可以是域名或域名地址簿的唯一标识ID。当前仅支持一个地址簿。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] destination_group_lists: 域名地址簿名称列表。
        :param pulumi.Input[builtins.str] destination_type: 访问目的的类型。domain：域名；group：域名地址簿。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] domain_lists: 域名列表。
        :param pulumi.Input[builtins.int] hit_cnt: 命中计数，表示该域名黑名单访问控制策略被触发的次数。
        :param pulumi.Input[builtins.str] internet_firewall_id: 互联网边界防火墙实例ID。
        :param pulumi.Input[builtins.int] last_hit_time: 最近命中时间戳，表示该域名黑名单访问控制策略最后一次被触发的时间。
        :param pulumi.Input[builtins.str] rule_id: 访问控制策略的唯一标识ID。
        :param pulumi.Input[builtins.bool] status: 域名黑名单访问控制策略的开关状态。false：关闭；true：开启。
        :param pulumi.Input[builtins.int] use_count: 该域名黑名单访问控制策略占用的策略数量。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DnsControlPolicyState.__new__(_DnsControlPolicyState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["description"] = description
        __props__.__dict__["destination"] = destination
        __props__.__dict__["destination_group_lists"] = destination_group_lists
        __props__.__dict__["destination_type"] = destination_type
        __props__.__dict__["domain_list_v1s"] = domain_list_v1s
        __props__.__dict__["domain_lists"] = domain_lists
        __props__.__dict__["hit_cnt"] = hit_cnt
        __props__.__dict__["internet_firewall_id"] = internet_firewall_id
        __props__.__dict__["last_hit_time"] = last_hit_time
        __props__.__dict__["rule_id"] = rule_id
        __props__.__dict__["sources"] = sources
        __props__.__dict__["status"] = status
        __props__.__dict__["use_count"] = use_count
        return DnsControlPolicy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        用户的唯一标识ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        策略的描述信息。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def destination(self) -> pulumi.Output[builtins.str]:
        """
        访问目的，可以是域名或域名地址簿的唯一标识ID。当前仅支持一个地址簿。
        """
        return pulumi.get(self, "destination")

    @property
    @pulumi.getter(name="destinationGroupLists")
    def destination_group_lists(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        域名地址簿名称列表。
        """
        return pulumi.get(self, "destination_group_lists")

    @property
    @pulumi.getter(name="destinationType")
    def destination_type(self) -> pulumi.Output[builtins.str]:
        """
        访问目的的类型。domain：域名；group：域名地址簿。
        """
        return pulumi.get(self, "destination_type")

    @property
    @pulumi.getter(name="domainListV1s")
    def domain_list_v1s(self) -> pulumi.Output[Sequence['outputs.DnsControlPolicyDomainListV1']]:
        return pulumi.get(self, "domain_list_v1s")

    @property
    @pulumi.getter(name="domainLists")
    def domain_lists(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        域名列表。
        """
        return pulumi.get(self, "domain_lists")

    @property
    @pulumi.getter(name="hitCnt")
    def hit_cnt(self) -> pulumi.Output[builtins.int]:
        """
        命中计数，表示该域名黑名单访问控制策略被触发的次数。
        """
        return pulumi.get(self, "hit_cnt")

    @property
    @pulumi.getter(name="internetFirewallId")
    def internet_firewall_id(self) -> pulumi.Output[builtins.str]:
        """
        互联网边界防火墙实例ID。
        """
        return pulumi.get(self, "internet_firewall_id")

    @property
    @pulumi.getter(name="lastHitTime")
    def last_hit_time(self) -> pulumi.Output[builtins.int]:
        """
        最近命中时间戳，表示该域名黑名单访问控制策略最后一次被触发的时间。
        """
        return pulumi.get(self, "last_hit_time")

    @property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> pulumi.Output[builtins.str]:
        """
        访问控制策略的唯一标识ID。
        """
        return pulumi.get(self, "rule_id")

    @property
    @pulumi.getter
    def sources(self) -> pulumi.Output[Sequence['outputs.DnsControlPolicySource']]:
        return pulumi.get(self, "sources")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.bool]:
        """
        域名黑名单访问控制策略的开关状态。false：关闭；true：开启。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="useCount")
    def use_count(self) -> pulumi.Output[builtins.int]:
        """
        该域名黑名单访问控制策略占用的策略数量。
        """
        return pulumi.get(self, "use_count")

